==> huaweicloudsdkdataartsstudio-3.1.68-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/search_bind_api_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SearchBindApiResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'records': 'list[AppBindApiInfo]'
    }

    attribute_map = {
        'total': 'total',
        'records': 'records'
    }

    def __init__(self, total=None, records=None):
        """SearchBindApiResponse

        The model defined in huaweicloud sdk

        :param total: 应用已绑定的api总个数
        :type total: int
        :param records: 应用已绑定的api列表
        :type records: list[:class:`huaweicloudsdkdataartsstudio.v1.AppBindApiInfo`]
        """
        
        super(SearchBindApiResponse, self).__init__()

        self._total = None
        self._records = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if records is not None:
            self.records = records

    @property
    def total(self):
        """Gets the total of this SearchBindApiResponse.

        应用已绑定的api总个数

        :return: The total of this SearchBindApiResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this SearchBindApiResponse.

        应用已绑定的api总个数

        :param total: The total of this SearchBindApiResponse.
        :type total: int
        """
        self._total = total

    @property
    def records(self):
        """Gets the records of this SearchBindApiResponse.

        应用已绑定的api列表

        :return: The records of this SearchBindApiResponse.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.AppBindApiInfo`]
        """
        return self._records

    @records.setter
    def records(self, records):
        """Sets the records of this SearchBindApiResponse.

        应用已绑定的api列表

        :param records: The records of this SearchBindApiResponse.
        :type records: list[:class:`huaweicloudsdkdataartsstudio.v1.AppBindApiInfo`]
        """
        self._records = records

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchBindApiResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/search_bind_api_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SearchBindApiResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'records': 'list[AppBindApiInfo]'
    }

    attribute_map = {
        'total': 'total',
        'records': 'records'
    }

    def __init__(self, total=None, records=None):
        r"""SearchBindApiResponse

        The model defined in huaweicloud sdk

        :param total: 应用已绑定的api总个数
        :type total: int
        :param records: 应用已绑定的api列表
        :type records: list[:class:`huaweicloudsdkdataartsstudio.v1.AppBindApiInfo`]
        """
        
        super(SearchBindApiResponse, self).__init__()

        self._total = None
        self._records = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if records is not None:
            self.records = records

    @property
    def total(self):
        r"""Gets the total of this SearchBindApiResponse.

        应用已绑定的api总个数

        :return: The total of this SearchBindApiResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this SearchBindApiResponse.

        应用已绑定的api总个数

        :param total: The total of this SearchBindApiResponse.
        :type total: int
        """
        self._total = total

    @property
    def records(self):
        r"""Gets the records of this SearchBindApiResponse.

        应用已绑定的api列表

        :return: The records of this SearchBindApiResponse.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.AppBindApiInfo`]
        """
        return self._records

    @records.setter
    def records(self, records):
        r"""Sets the records of this SearchBindApiResponse.

        应用已绑定的api列表

        :param records: The records of this SearchBindApiResponse.
        :type records: list[:class:`huaweicloudsdkdataartsstudio.v1.AppBindApiInfo`]
        """
        self._records = records

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchBindApiResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
